@@ -1,6 +1,3 @@
-from .client import Tair
-from .cluster import TairCluster
-
 from redis.asyncio.connection import (
     BlockingConnectionPool,
     Connection,
@@ -31,6 +28,9 @@ from redis.exceptions import (
     WatchError,
 )
 
+from tair.asyncio.client import Tair
+from tair.asyncio.cluster import TairCluster
+
 TairError = RedisError
 
 __all__ = [
